Improve this Doc

# Error: $interpolate:nochgmustache
Redefinition of start/endSymbol incompatible with MessageFormat extensions

    angular-message-format.js currently does not allow you to use custom start and end symbols for interpolation.

## Description

You have redefined `$interpolate.startSymbol`/`$interpolate.endSymbol` and also loaded the `ngMessageFormat` module (provided by angular-message-format.min.js) while creating your injector.

`ngMessageFormat` currently does not support redefinition of the startSymbol/endSymbol used by `$interpolate`. If this is affecting you, please file an issue and mention @chirayuk on it. This is intended to be fixed in a future commit and the github issue will help gauge urgency.

For more information about the MessageFormat syntax in interpolation expressions, please refer to MessageFormat extensions section at Angular i18n MessageFormat